/* LevelSize.java

	Purpose:
		
	Description:
		
	History:
		Mon Dec 02 12:28:10 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Determines the width of the ring per level.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class LevelSize extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		unit,
		value
	}

	public LevelSize() {
	}

	/**
	 * Constructs with value and unit.
	 */
	public LevelSize(Number value, String unit) {
		setValue(value);
		setUnit(unit);
	}

	/**
	 * Returns how to interpret levelSize.value.
	 * <ul>
	 * <li>{@code percentage} gives a width relative to result of outer radius minus inner radius.</li>
	 * <li>{@code pixels} gives the ring a fixed width in pixels.</li>
	 * <li>{@code weight} takes the remaining width after percentage and pixels, and distributes it across all "weighted" levels. The value relative to the sum of all weights determines the width.</li>
	 * </ul>
	 * <p>
	 * Default: "weight"
	 */
	public String getUnit() {
		return getAttr(Attrs.unit, "weight").asString();
	}

	/**
	 * Sets how to interpret levelSize.value.
	 * <ul>
	 * <li>{@code percentage} gives a width relative to result of outer radius minus inner radius.</li>
	 * <li>{@code pixels} gives the ring a fixed width in pixels.</li>
	 * <li>{@code weight} takes the remaining width after percentage and pixels, and distributes it across all "weighted" levels. The value relative to the sum of all weights determines the width.</li>
	 * </ul>
	 */
	public void setUnit(String unit) {
		if (!("percentage".equals(unit) || "pixels".equals(unit) || "weight".equals(unit)))
			throw new IllegalArgumentException("Unsupported unit: [" + unit + "]");
		setAttr(Attrs.unit, unit);
	}

	/**
	 * Returns the value used for calculating the width of the ring.
	 * Its' affect is determined by levelSize.unit.
	 * <p>
	 * Default: 1
	 */
	public Number getValue() {
		return getAttr(Attrs.value, 1).asNumber();
	}

	/**
	 * Sets the value used for calculating the width of the ring.
	 * Its' affect is determined by levelSize.unit.
	 */
	public void setValue(Number value) {
		setAttr(Attrs.value, value);
	}
}
