/* HistogramPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Thu Nov 21 11:17:27 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.json.JavaScriptValue;

/**
 * An option for histogram plot
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class HistogramPlotOptions extends SeriesPlotOptions {
	private enum Attrs implements PlotAttribute {
		binsNumber, binWidth
	}

	/**
	 * Returns a preferable number of bins.
	 * It is a suggestion, so a histogram may have a different number of bins.
	 * By default it is set to the square root of the base series' data length.
	 * Available options are: {@code square-root}, {@code sturges}, {@code rice}.
	 * You can also define a function which takes a baseSeries as a parameter and should return a positive integer.
	 * <p>
	 * Default: "square-root"
	 */
	public Object getBinsNumber() {
		return getAttr(Attrs.binsNumber, "square-root").asValue();
	}

	/**
	 * Sets a preferable number of bins.
	 * It is a suggestion, so a histogram may have a different number of bins.
	 * Available options are: {@code square-root}, {@code sturges}, {@code rice}.
	 */
	public void setBinsNumber(String binsNumber) {
		if (!("square-root".equals(binsNumber) || "sturges".equals(binsNumber) || "rice".equals(binsNumber)))
			throw new IllegalArgumentException("Unsupported binsNumber: [ " + binsNumber + " ]");
		setAttr(Attrs.binsNumber, binsNumber);
	}

	/**
	 * Sets a preferable number of bins.
	 * It is a suggestion, so a histogram may have a different number of bins.
	 */
	public void setBinsNumber(int binsNumber) {
		setAttr(Attrs.binsNumber, binsNumber);
	}

	/**
	 * Sets a preferable number of bins.
	 * It is a suggestion, so a histogram may have a different number of bins.
	 * You can define a function which takes a baseSeries as a parameter and should return a positive integer.
	 */
	public void setBinsNumber(JavaScriptValue binsNumber) {
		setAttr(Attrs.binsNumber, binsNumber);
	}

	/**
	 * Returns the width of each bin. By default the bin's width is calculated
	 * as {@code (max - min) / number of bins}.
	 * This option takes precedence over binsNumber.
	 * <p>
	 * Default: null
	 */
	public Number getBinWidth() {
		return getAttr(Attrs.binWidth, null).asNumber();
	}

	/**
	 * Sets the width of each bin. By default the bin's width is calculated
	 * as {@code (max - min) / number of bins}.
	 * This option takes precedence over binsNumber.
	 */
	public void setBinWidth(Number binWidth) {
		setAttr(Attrs.binWidth, binWidth);
	}
}
