/* SunburstPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Mon Dec 02 12:10:11 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import java.util.List;

import org.zkoss.chart.Level;
import org.zkoss.chart.LevelSize;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.TraverseUpButton;
import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.lang.Generics;

/**
 * An option for sunburst plot
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class SunburstPlotOptions extends PiePlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		allowTraversingTree,
		levelIsConstant,
		levels,
		levelSize,
		rootId,
		traverseUpButton
	}

	/**
	 * When enabled the user can click on a point which is a parent and zoom in
	 * on its children.
	 * <p>
	 * Default: false
	 */
	public boolean isAllowTraversingTree() {
		return getAttr(Attrs.allowTraversingTree, false).asBoolean();
	}

	/**
	 * When enabled the user can click on a point which is a parent and zoom in
	 * on its children.
	 */
	public void setAllowTraversingTree(boolean allowTraversingTree) {
		setAttr(Attrs.allowTraversingTree, allowTraversingTree);
	}

	/**
	 * Used together with the levels and allowTraversingTree options.
	 * When set to false the first level visible when drilling is considered to be level one.
	 * Otherwise the level will be the same as the tree structure.
	 * <p>
	 * Default: true
	 */
	public boolean isLevelIsConstant() {
		return getAttr(Attrs.levelIsConstant, true).asBoolean();
	}

	/**
	 * Used together with the levels and allowTraversingTree options.
	 * When set to false the first level visible when drilling is considered to be level one.
	 * Otherwise the level will be the same as the tree structure.
	 */
	public void setLevelIsConstant(boolean levelIsConstant) {
		setAttr(Attrs.levelIsConstant, levelIsConstant);
	}

	/**
	 * Set options on specific levels. Takes precedence over series options,
	 * but not point options.
	 * <p>
	 * Default: null
	 */
	public List<Level> getLevels() {
		return Generics.cast(getAttr(Attrs.levels, null).asValue());
	}

	/**
	 * @param levels
	 * @see #getLevels()
	 */
	public void setLevels(List<Level> levels) {
		setAttr(Attrs.levels, levels);
	}

	/**
	 * Returns options of determining the width of the ring per level, if any.
	 * Otherwise, create a new one.
	 */
	public LevelSize getLevelSize() {
		LevelSize levelSize = (LevelSize) getAttr(Attrs.levelSize);
		if (levelSize == null) {
			levelSize = new LevelSize();
			setLevelSize(levelSize);
		}
		return levelSize;
	}

	/**
	 * Sets options of determining the width of the ring per level.
	 */
	public void setLevelSize(LevelSize levelSize) {
		setAttr(Attrs.levelSize, levelSize);
	}

	/**
	 * Returns which point to use as a root in the visualization.
	 * <p>
	 * Default: null
	 */
	public String getRootId() {
		return getAttr(Attrs.rootId, null).asString();
	}

	/**
	 * Sets which point to use as a root in the visualization.
	 */
	public void setRootId(String rootId) {
		setAttr(Attrs.rootId, rootId);
	}

	/**
	 * Returns options for the button appearing when traversing down in a treemap, if any.
	 * Otherwise, create a new one.
	 */
	public TraverseUpButton getTraverseUpButton() {
		TraverseUpButton traverseUpButton = (TraverseUpButton) getAttr(Attrs.traverseUpButton);
		if (traverseUpButton == null) {
			traverseUpButton = new TraverseUpButton();
			setTraverseUpButton(traverseUpButton);
		}
		return traverseUpButton;
	}

	/**
	 * Sets options for the button appearing when traversing down in a treemap.
	 */
	public void setTraverseUpButton(TraverseUpButton traverseUpButton) {
		setAttr(Attrs.traverseUpButton, traverseUpButton);
	}
}
