/* TargetOptions.java

	Purpose:
		
	Description:
		
	History:
		Fri Nov 29 12:48:02 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Color;
import org.zkoss.chart.LinearGradient;
import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.RadialGradient;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * All options related with look and position of targets.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class TargetOptions extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		borderColor, borderWidth, color, height, width
	}

	/**
	 * Returns the border color of the rectangle representing the target.
	 * When not set, the point's border color is used.
	 * <p>
	 * Default: null
	 */
	public Color getBorderColor() {
		return (Color) getAttr(Attrs.borderColor, null).asValue();
	}

	/**
	 * Sets the border color of the rectangle representing the target.
	 */
	public void setBorderColor(Color borderColor) {
		setAttr(Attrs.borderColor,borderColor);
	}

	/**
	 * Sets the border color of the rectangle representing the target.
	 */
	public void setBorderColor(String borderColor) {
		setBorderColor(new Color(borderColor));
	}

	/**
	 * Returns the border width of the rectangle representing the target.
	 * <p>
	 * Default: 0
	 */
	public Number getBorderWidth() {
		return getAttr(Attrs.borderWidth, null).asNumber();
	}

	/**
	 * Sets the border width of the rectangle representing the target.
	 * <p>
	 * Default: 0
	 */
	public void setBorderWidth(Number borderWidth) {
		setAttr(Attrs.borderWidth, borderWidth);
	}

	/**
	 * Returns the color of the rectangle representing the target.
	 * When not set, point's color (if set in point's options - color)
	 * or zone of the target value (if zones or negativeColor are set)
	 * or the same color as the point has is used.
	 * <p>
	 * Default: null
	 */
	public Color getColor() {
		return (Color) getAttr(Attrs.color, null).asValue();
	}

	/**
	 * Sets the color of the rectangle representing the target.
	 */
	public void setColor(Color color) {
		setAttr(Attrs.color, color);
	}

	/**
	 * Sets the color of the rectangle representing the target.
	 */
	public void setColor(String color) {
		setColor(new Color(color));
	}

	/**
	 * Sets the color of the rectangle representing the target.
	 */
	public void setColor(LinearGradient color) {
		setColor(new Color(color));
	}

	/**
	 * Sets the color of the rectangle representing the target.
	 */
	public void setColor(RadialGradient color) {
		setColor(new Color(color));
	}

	/**
	 * Returns the height of the rectangle representing the target.
	 * <p>
	 * Default: 3
	 */
	public Number getHeight() {
		return getAttr(Attrs.height, 3).asNumber();
	}

	/**
	 * Sets the height of the rectangle representing the target.
	 */
	public void setHeight(Number height) {
		setAttr(Attrs.height, height);
	}

	/**
	 * Returns the width of the rectangle representing the target.
	 * Could be set as a pixel value or as a percentage of a column width.
	 * <p>
	 * Default: "140%"
	 */
	public Object getWidth() {
		return getAttr(Attrs.width, "140%").asValue();
	}

	/**
	 * Sets the width of the rectangle representing the target.
	 * Could be set as a pixel value.
	 */
	public void setWidth(Number width) {
		setAttr(Attrs.width, width);
	}

	/**
	 * Sets the width of the rectangle representing the target.
	 * Could be set as a percentage of a column width.
	 */
	public void setWidth(String width) {
		setAttr(Attrs.width, width);
	}
}
